Welcome to ``pylint-sort-functions``'s documentation!
======================================================

A pylint plugin that enforces alphabetical sorting of functions and methods within Python modules and classes.

.. toctree::
    :maxdepth: 2
    :caption: Getting Started:

    introduction
    usage
    cli
    workarounds

.. toctree::
    :maxdepth: 2
    :caption: Configuration:

    pylintrc
    sorting

.. toctree::
    :maxdepth: 2
    :caption: Reference:

    api
    developer
    claude
    testing
    validation-system
    release
    changelog
    roadmap

Quick Links
-----------

* **Having issues?** Check :doc:`workarounds` for immediate solutions
* **Want new features?** See our :doc:`roadmap` for planned improvements
* **Found a bug?** Report it on `GitHub Issues <https://github.com/hakonhagland/pylint-sort-functions/issues>`_

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
